#
# spec file for package waylyrics
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           waylyrics
Version:        0.3.13
Release:        1.4
Summary:        The furry way to show desktop lyrics
License:        MIT
URL:            https://github.com/waylyrics/waylyrics
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo >= 1.76.0
BuildRequires:  cargo-packaging
BuildRequires:  dbus-1-devel
BuildRequires:  gettext
BuildRequires:  gtk4-devel
BuildRequires:  libgraphene-devel
BuildRequires:  mimalloc-devel
BuildRequires:  openssl-devel

%description
The furry way to show desktop lyrics, and simple universal desktop lyrics made with GTK4 and love.

%lang_package

%prep
%autosetup -a1 -p0

%build
export WAYLYRICS_THEME_PRESETS_DIR=%{_datadir}/waylyrics/themes
%{cargo_build} --locked

%install
export WAYLYRICS_THEME_PRESETS_DIR=%{_datadir}/waylyrics/themes
%{cargo_install} --locked

install -dm755 %{buildroot}%{_datadir}/waylyrics
cp -r themes %{buildroot}%{_datadir}/waylyrics/

install -Dm644 "metainfo/io.github.waylyrics.Waylyrics.desktop" -t %{buildroot}%{_datadir}/applications/
install -Dm644 "metainfo/io.github.waylyrics.Waylyrics.gschema.xml" -t %{buildroot}%{_datadir}/glib-2.0/schemas/
cp -r res/icons %{buildroot}%{_datadir}/icons

# Locale files
(
    cd locales
    for po in $(find . -type f -name '*.po')
    do
        mkdir -p %{buildroot}%{_datadir}"/locale/${po#/*}"
        msgfmt -o %{buildroot}%{_datadir}"/locale/${po%.po}.mo" ${po}
    done
)
%find_lang %{name} %{name}.lang

%check
export WAYLYRICS_THEME_PRESETS_DIR=%{_datadir}/waylyrics/themes
%{cargo_test} --locked --features=offline-test

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/waylyrics/
%{_datadir}/applications/io.github.waylyrics.Waylyrics.desktop
%{_datadir}/glib-2.0/schemas/io.github.waylyrics.Waylyrics.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/io.github.waylyrics.Waylyrics.svg

%files lang -f %{name}.lang

%changelog
* Sat Jun 29 2024 xtexchooser@duck.com
- Update to version 0.3.13:
  * chore: release v0.3.13
  * fix: missing import statement
  * fix: do not remove original lyric on extracting translated ones
  * docs(readme): add `ncmpcpp` via mpd-mpris
  * chore: bump dependencies
* Sat Jun 22 2024 xtexchooser@duck.com
- Update to version 0.3.12:
  * chore: release v0.3.12
  * fix: extract lyric lines should compare start_time
  * fix: `extract-translated-lyric` flag is ignored
  * docs: fix typo
  * chore(log): add log for textdomain to use
* Thu Jun  6 2024 xtexchooser@duck.com
- Update to version 0.3.11:
  * chore: release v0.3.11
  * docs(install): user-fiendly version (#240)
  * feat: extract translated lyric from local LRC - this only affects behaviour on loading local lyric via player hint - close #241
  * feat: try load local translated lyric with ISO-639-1 code ,close #165
  * build(deps): bump toml_edit from 0.22.12 to 0.22.13
  * build(deps): bump async-channel from 2.2.1 to 2.3.1
  * build(deps): bump anyhow from 1.0.82 to 1.0.86
  * build(deps): bump mimalloc from 0.1.41 to 0.1.42
  * build(deps): bump the serde group with 2 updates
  * Update INSTALLATION.md
  * Update INSTALLATION.en.md
  * Update INSTALLATION.md
  * Update INSTALLATION.en.md
  * Update INSTALLATION.md
  * Update INSTALLATION.en.md
  * Update INSTALLATION.md
  * Update INSTALLATION.en.md
  * 修复了一些安装文档的小问题
* Wed Jun  5 2024 xtexchooser@duck.com
- Update to version 0.3.10:
  * chore: release v0.3.10
  * fix(log): i18n bind result will not be logged
* Sun May 26 2024 xtexchooser@duck.com
- Update to version 0.3.9:
  * chore: release v0.3.9
  * fix(windows): auto connect to active player
  * fix(test): do not test time
  * build: enable import lyric feature for windows
  * docs(readme): intro musicfox, TUI music player supports SMTC [ci skip]
  * enhance: workaround for musicfox v4.4.0 [ci skip]
  * Fix Chinese translation
  * Set title for lyrics file selection dialog
* Tue Apr 30 2024 xtexchooser@duck.com
- Update to version 0.3.8:
  * chore: release v0.3.8
  * i18n: translate 'import lyric' & translated/original lyric
  * build: do not strip binary by default [ci skip]
  * chore(deps): bump dependencies [ci skip]
  * feat: import local lrc in tray & csd menu
  * docs(readme): intro waylyrics-sakura-translator [ci skip]
  * chore: release v0.3.7
  * feat: emit LoadLyricCache signal on lyric cache load
  * chore: release v0.3.6
  * fix(typo): import-lrc -> import-lyric
  * feat: select local LRC file to import
  * refactor: inline variable "text"
  * Avoid starting with article in summary
  * build: migrate to ksni 0.2.2
  * feat: allow LRC line that starts with [xxx] without ':'
  * fix: disable local lrc hint on `enable-local-lyric=false`
  * docs(install-en): add flatpak installation link
  * docs(install): add flatpak installation link
  * fix: missing import
  * feat: disable loading local lyric
  * refactor: Change net-test to offline-test
  * chore: add archlinuxcn in installation guide
  * feat(tray): refetch-lyric for windows
  * refactor: store dbus connection instead of gapplication
* Fri Apr 26 2024 xtexchooser@duck.com
- Update to version 0.3.5:
  * chore: release v0.3.5
  * feat: emit NewLyricCache signal on lyric cache update
  * feat: reload lyric from cache
  * build(test): set profile.test.debug a boolean
  * chore: release v0.3.4
  * Fix Exec in desktop file
  * chore(metainfo): use v0.3.3 tag
  * chore(metainfo): add screenshot of search window
  * chore(metainfo): fix warnings
  * chore: release v0.3.3
  * chore(desktopfile): remove action `Launch`
  * chore(metainfo): h3 tags are not supported
  * chore: release v0.3.2
  * fix: enum tuple variant cannot be destrcucted by tuple matching
  * fix(readme): broken link of desktop file
  * Use patched ksni to solve tray issue in flatpak (thanks to @taoky)
  * chore: make extracting values from tuples more readable
  * chore: use for loop to refactor items appending in ui_section & play_section
  * chore: use for loop to refactor entries appending in imp.vbox
  * log(tray): do not flood start_time on smtc
  * ci: fix documents deploy CI
  * ci: remove microsoft-prod.list
  * ci: fix test.yml
  * chore: release v0.3.1
  * feat: set search-window ColumnView row padding in themes
  * docs(changelog): update changelog
  * Add replaces & launchable
  * Update metainfo to v0.3.0
* Fri Apr 26 2024 xtexchooser@duck.com
- Update to version 0.3.0:
  * docs(changelog): update changelog
  * chore: release v0.3.0
  * fix(ci): new schema path
  * docs(install): update packaging script
  * BREAKING CHANGE: formalize app id & restructure files~
  * Fix missing wayland icon
  * Add metainfo
  * Change filenames
  * Change screenshot 1
  * Add screenshots
  * fix: set titlebar before set decorated
  * log: set time diff log level to TRACE so we will not flood debug log
  * log: mpris position delay
  * refactor: pass WeakRef<Window> to register_sync_task
  * fix(i18n): en_US translation
  * revert: "Translate display modes"
  * Translate display modes
  * align -> alignment
  * docs(changelog): update changelog
  * chore: release v0.2.21
  * fix: stop lyric update when show_lyric_on_pause not set on pause
  * docs(changelog): update changelog
  * chore: release v0.2.20
  * build: remove git dependencies
  * docs(changelog): update changelog
* Sat Apr 20 2024 xtexchooser@duck.com
- Update to version 0.2.19:
  * chore: release v0.2.19
  * fix(i18n): load i18n on windows
  * fix: underscore not showing in display mode menu
  * build: enable i18n for msvc build
  * docs(build): gettext-rs on windows cannot builds out-of-box with MSVC
  * fix: use '/' as splitte on searchbox creating
  * feat: use song_search_detailed in search box to apply aliases
  * enhance: apply alias for artist name on `netease`
  * enhance: make fuzzy-match weight more than length based match
  * enhance: fine-tune fuzzy match factor
  * feat: convert zh-hans/zh-hant in fuzzy match with opencc
  * chore: bump dependencies
  * build(windows): add build script
  * docs(changelog): update changelog
* Sat Apr 20 2024 xtexchooser@duck.com
- Update to version 0.2.18:
  * chore: release v0.2.18
  * fix: set paused as false after resumed to playing
  * log: print control status at trace level
  * feat: hide lyric on pause
  * docs(changelog): update changelog
* Fri Apr 12 2024 xtexchooser@duck.com
- Update to version 0.2.17:
  * chore: release v0.2.17
  * feat: restart in tray-icon for windows
  * docs(readme): update missing translation
  * fix: gtk4 freezes on `Window::close` on windows
  * enhance: support LastUpdateTime on windows
  * chore: switch to upstream `tray-icon`
  * chore(deps): bump dependencies
  * fix: feature gate for unix should be `cfg(unix)`
  * chore: release v0.2.16
  * feat: initial tray-icon support for windows
  * chore(test): cleanup unused imports
  * build(deps): bump h2 from 0.4.3 to 0.4.4
  * docs(changelog): update changelog
  * docs(readme): the only compatible player on windows
  * build: add icon for win32 build
* Wed Apr  3 2024 xtexchooser@duck.com
- Update to version 0.2.15:
  * chore: release v0.2.15
  * feat: full mouse click-through for windows
  * docs(changelog): update changelog
  * fix: windows smtc position
  * fix: misuse of `windows-rs`
  * ci: reset pkgrel after a pkgver bump
  * docs(readme): intro windows user directories
  * chore: release v0.2.14
  * fix: do workarounds for windows-rs bug
  * fix: duplicated import
  * fix: wrong import path
  * feat: initial support for Windows SMTC
  * refactor: cleanup old code
  * docs(install): build on windows
  * build: make gettext, openssl, journald optional
  * revert: vendored -> openssl
  * refactor: define OS-specified helpers in a trait
  * refactor: rename `list_player_names` to `list_players`
  * refactor: extract `try_sync_track` and `reconnect_player` from `interop::*`
  * build(deps): bump actions/checkout from 3 to 4
  * build(deps): bump orhun/git-cliff-action from 2 to 3
  * build(deps): bump actions/upload-artifact from 3 to 4
  * Update dependabot.yml
  * ci: Automatically update AUR PKGBUILD
  * build(deps): bump documented from 0.3.0 to 0.4.0
  * docs(readme): autoLyric `C/C++`
  * refactor: use `bind_shortcut` in switch-passthrough
  * chore(deps): bump dependencies
  * build: reduce binary size
  * docs(readme): musixfox-go released the required patch [ci skip]
  * Revert "feat: select labels by origin/translation in theme"
  * build(rpm): packit is no longer needed [ci skip]
  * chore: example environment is no longer required [ci skip]
  * docs(changelog): update changelog
* Sat Mar 30 2024 xtexChooser <xtexchooser@duck.com>
- Remove old rust ICE workaround
* Sat Mar 23 2024 xtexchooser@duck.com
- Update to version 0.2.13:
  * chore: release v0.2.13
  * feat: blacklist players by name/identity
  * build(dep): update reqwest to 0.12
  * feat: fix secondary lyric will not end
  * build(deps): bump mio from 0.8.10 to 0.8.11
  * revert: "Update README.md"
  * Update README.md
  * refactor: use builder api in widget setup
  * feat: add theme no-background [ci skip]
  * docs(readme): intro listen1 [ci skip]
  * docs(readme): complain some bad support [ci skip]
  * docs(readme): list recommended players in chart [ci skip]
  * refactor: remove repeated bind-shortcut code
  * chore: fix missing bracket
  * refactor: do not set display mode manually
  * enhance: replace extension with PathBuf::set_extension
  * refactor: implement Debug for dyn LyricProvider
  * refactor: remove unneeded player_meta helper
  * docs(changelog): update changelog
  * feat: select labels by origin/translation in theme
* Sat Mar  2 2024 xtexchooser@duck.com
- Update to version 0.2.12:
  * chore: release v0.2.12
  * feat: set Priority::HIGH for lyric_scroll
  * docs(readme): go-musicfox merged fix-position [ci skip]
  * docs(build): fix install command for schema [ci skip]
  * Update waylyrics.spec
  * Update INSTALLATION.md
  * docs(build): update packaging docs
  * chore: remove CSS stylelintrc
  * docs(install): show packaging status
* Sat Feb 24 2024 xtexchooser@duck.com
- Package language files
- Update to version 0.2.11:
  * fix: show_both mode place origin to above if no translation
  * docs(changelog): update changelog
  * enhance: switch-passthrough in tray-icon without restart
  * docs(readme): remove dead `flutter-netease-music`
  * fix: hsl color format
  * docs(changelog): update changelog
  * chore: release v0.2.11
  * fix: use hsla for transparent window background
  * refactor: use `clone!` macro rather than calling upgrade/downgrade manually
  * perf: store default MainContext
  * chore: bump dependencies
  * fix: restart in tray-icon set click-through
  * ci: disable changelog on tag due to shitty failure [ci skip]
  * docs(changelog): update changelog
  * chore: release v0.2.10
  * refactor: move logic-related fields to Window::new
  * revert: "feat: (optional) select labels by translation/origin"
  * feat: (optional) select labels by translation/origin
  * feat(theme): new style
  * style(theme): format CSS with Prettier and Stylelint
  * feat: set mouse click-through in GSettings
  * feat: split popover menu to UI section and Play section
  * feat: set lyric-display-mode in GSettings
  * refactor: cleanup `set_lyric_with_mode` [ci skip]
  * docs(changelog): update changelog
  * chore: release v0.2.9
  * i18n: translate lyric align
  * feat!: set lyric align mode on run time
  * chore: clean up theme comments
  * chore: remove invalid github template
  * i18n: translate display_mode
  * feat: show icons on tray-icon menu
  * feat: only show set-lyric button when avaliable
  * i18n: translate length to 时长
  * docs(changelog): update changelog
  * ci: fix changelog ci skipped unexpectedly
  * chore: release v0.2.8
  * build(rpm): package with i18n files
  * fix: incomplete i18n in menu
  * docs(build): add gettext to dependencies
  * i18n: add translation for Simplefied Chinese
  * feat: i18n support
  * style: package_name as a constant [ci-skip]
  * build: make global theme presets optional
  * chore: remove unnessacary use of Arc<dyn LyricProvider>
  * ci: do not flood commit logs
  * docs(changelog): update changelog
  * build(rpm): add icon
  * docs(changelog): update changelog
  * docs(readme): update readme
  * docs(changelog): update changelog
  * feat: show tooltip for search entries
  * docs(changelog): update changelog
  * ci: update changelog on each commit
  * feat: sort search result by fuzzy-match weight
  * refactor: skip fuzzy-match in it's block
  * docs(changelog): update changelog
  * fix: changelog CI need write permission
  * ci: generate changelogs for master
  * chore: release v0.2.7
  * enhance: migrate to better dice-coefficient lib
  * feat: skip fuzzy-match if we got only title in metadata
  * log: log detailed likelihood with trace-level
  * feat: fuzzy-match lyrics with Sorensen-Dice coefficient
  * enhance: remove unnessacary global variable for PlayerId's
  * feat: restart waylyrics in tray-icon
  * chore: release v0.2.6
  * fix: missing feature gate for re-export in sync
  * feat: optionally start tray-icon service
  * feat(tray-icon): PlayAction control
  * feat: initial tray-icon support
  * todo: impl real tray-icon functions
  * feat: set lyric display mode in run time
  * refactor: remove repeated function prefix
  * chore: release v0.2.5
  * fix: repeated docs appends to commented config.toml
  * docs(config): lyric-align accepts CamelCase value
  * fix: append comments with `documented`
  * refactor: move config.rs to config/
  * feat: generate comments for config
  * build: add optional ksni dep
  * fix: remove `hide_label_on_empty_text = false` support
  * fix: do not hide below label in set_lyric
  * refactor: move search_window to crate::app
  * fix: remove `hide_label_on_empty_text = false` support
  * fix: do not hide below label in set_lyric
  * refactor: move search_window to crate::app
  * chore: release 0.2.4
  * fix: do not show lyric on `Stopped` status
  * feat: hide default text on idle
  * feat: set unsupported reason on below label
  * build: rename feature to 'action-event' rather than tray-icon
  * log: log reveiced action event
  * build: make tray-icon feature optional
  * fix: re-export play-action channel
  * fix: should re-export PlayAction
  * feat: invoke ui actions with mpsc::channel
  * refactor: rename to play_action
  * refactor: move UI-related actions to crate::app::actions
  * refactor: rename AppAction to PlayAction
  * style: remove unused Downgrade import
  * feat: invoke app actions with mpsc::channel
  * chore(dep): migrate to gtk4-rs 0.8.0
  * docs(readme): waybar supports all wlroots-based compositors
  * other(logo): white shade for text and logo
  * other(logo): make logo not so shining in dark background [ci skip]
  * docs(readme): move chat banners to center block [ci skip]
  * docs(readme): add logo and intro video [ci skip]
  * docs(contribute): introduce Conventional Commit [ci skip]
* Wed Feb 14 2024 xtexchooser@duck.com
- Update to version 0.2.3:
  * feat: add `trans` theme [ci skip]
  * chore: release 0.2.3
  * ci: migrate to dtolnay/rust-toolchain
  * feat: allow to show origin lyric in above
  * fix: set 20ms as default lyric update interval
  * feat: set empty label explictly
  * refactor: apply clippy fix [ci skip]
  * chore: remove unreachable `title.unwrap_or()` call
  * doc: restate outdated doc of `TrackMeta`
  * doc: `lollypop`, GTK3-based local music player
  * feat: intro `is_likely_songid` for songid verification
  * doc: firefox via Plasma Integration [ci skip]
  * doc: explain more fields in `Config`
  * doc: add `osdlyrics` to alternatives [ci skip]
  * doc: play with musicfox need position fix patch
  * refactor: rename confusing `match_lyric` to `verify_lyric` [ci skip]
  * test: add unit tests for QQMusic::init
* Sat Feb 10 2024 xtexchooser@duck.com
- Update to version 0.2.2:
  * chore: release `v0.2.2`
  * build: Add ability to disable tests require network
  * ci: test qqmusic provider initializing
  * fix: QQMusic::init should panic on `Err()` rather than `Ok()`
* Fri Feb  9 2024 xtexchooser@duck.com
- Update to version 0.2.1:
  * chore: release 0.2.1
  * build: improve test build time
  * test: move out doctest for `get_lrc_path`
  * test: move unit tests to inside `src/`
  * refactor: rename `get_lyric` to `parse_lyric` [ci skip]
  * refactor: setup `QQMusic` with `init()` call
  * doc(install): download pre-built executables [ci skip]
  * doc(install): explain build environment variable
  * ci: run real test in CI
  * test: test LRC parsing
  * doc: define `lrc_iter` behaviour
  * refactor: impl into_owned for LyricLine
  * test: test netease lyric get & parse
  * refactor: remove `CONFIG_HOME`
  * chore: remove unused import
  * breaking(ui): drop `SIGUSR` control support
  * refactor: make `init_dirs` a public method so we could write tests
  * chore: release 0.2.0
  * style: define `glib-macros` under `gtk`
  * doc(readme): remove `lx-music` because it's dead [ci skip]
  * chore(doc): add `musicfox`, a TUI based music player [ci skip]
  * fix: hint support for musicfox
  * chore(doc): update doc for youtube-music [ci skip]
  * chore: drop support for ncm-gtk legacy name
  * feat: add support for musicfox
  * chore(doc): update translation [ci skip]
  * chore(doc): update alternatives [ci skip]
* Wed Feb  7 2024 xtexchooser@duck.com
- Update to version 0~git486:
  * fix: override user theme
  * fix: ignore invalid LRC lines
  * code quality: remove unused last_played_lyric_index
  * chore: clean up lyric scroll
  * chore: replace `with_borrow_mut` with `set` [ci skip]
  * chore: openSUSE official package thanks to @xtexChooser
  * fix: desktop file does not need a launch action [ci skip]
  * chore(doc): mention desktop file for global shortcut
  * refactor: move out update_lyric
  * build(rpm): fix install
  * chore: intro openssl/vendored to vendored feature [ci skip]
* Fri Feb  2 2024 xtexChooser <xtexchooser@duck.com>
- Remove tar.zst packaged sources, keep obscpio only
- Change versioning to follow package versioning guidelines
* Fri Feb  2 2024 xtexChooser <xtexchooser@duck.com>
- Remove rpm "Group"
* Thu Feb  1 2024 xtexChooser <xtexchooser@duck.com>
- Update vendored crates
* Thu Feb  1 2024 xtexChooser <xtexchooser@duck.com>
- Init waylyrics from upstream commit aed689ef481dd2ddf22cefc0d175fabee481cdb8
